/* maemo vpnc-gui
 * 
 * Copyright (c) 2007 Michael "ScriptKiller" Arndt
 * http://scriptkiller.de/
 * <scriptkiller@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 */

#ifndef __PROFILES_LAUNCHER_VPNC_H__
#define __PROFILES_LAUNCHER_VPNC_H__

void profiles_launcher_vpnc_init();
void profiles_launcher_vpnc_set_event_callback(void (*callback)(struct profile *, gint event, gpointer data));
void profiles_launcher_vpnc_connect(struct profile *p);
void profiles_launcher_vpnc_disconnect(struct profile *p);
void profiles_launcher_vpnc_feed_password(gchar *pw);

#endif
